function [Speaker, Mic] = CreateSpeakerAndMic(SoundCard, Fs, SamplesPerFrame, numberOfChannels) 
% CreateSpeakerAndMic - create objects for reading and playing audio
% 
% This function creates a speaker and a microphone object
% 
% [Speaker, Mic] = CreateSpeakerAndMic(SoundCard, Fs, SamplesPerFrame,
% numberOfChannels)
% 
% Input:
% SoundCard - String containing the name of the sound card (as appears in
% MATLAB)
% Fs - Sampling frequency
% SamplesPerFrame - Frame size
% numberOfChannels - Number of Channels
% 
% Output:
% Speaker - Speaker object for playing audio
% Mic - Microphone object for recording audio
% 
% Last modified 09.12.2014 by
% Frank Hetland & Leo Hauge

% Create microphone object

Mic = dsp.AudioRecorder(...
    'DeviceName',SoundCard,... 
    'NumChannels',numberOfChannels,... 
    'SampleRate',Fs,...
    'DeviceDataType','Determine from output data type',...
    'BufferSizeSource','Property',...
    'BufferSize',SamplesPerFrame,...
    'QueueDuration',2*(SamplesPerFrame+1)/Fs,...
    'SamplesPerFrame',SamplesPerFrame,...
    'OutputDataType','double',...
    'ChannelMappingSource','Auto');


% Create Speaker object
Speaker = dsp.AudioPlayer(...
    'DeviceName',SoundCard,... 
    'SampleRate',Fs,...
    'DeviceDataType','Determine from input data type',...
    'BufferSizeSource','Property',...
    'BufferSize',SamplesPerFrame,...
    'QueueDuration',2*(SamplesPerFrame+1)/Fs,...
    'ChannelMappingSource','Auto');
end