function noise = ambientNoise(handles)
% ambientNoise - ambient noise generation function
% 
% This function creates noise simulating underwater acoustic noise
% pollution. It has been made according to figure 11.8. page 330 in Hovem's
% Marine Acoustics book from 2
% 
% noise = ambientNoise(handles)
% 
% Input:
% handles - object where:
% handles.settings.Fs - sampling frequency
% handles.settings.samplesPerFrame - samples per frame 
% handles.settings.seastate - sea state 
% handles.settings.numberOfChannels - number of channels
% 
% Output:
% noise - with 17 dB decreas per decade from 1 kHz
% 
% Last modified 09.12.2014 by
% Frank Hetland & Leo Hauge


Fs=handles.settings.Fs;
fSize=handles.settings.samplesPerFrame;
sS=handles.settings.seastate; 
% Fs = 96000;
% fSize = 16*1024;
% sS = 1;
% % nCh=handles.settings.numberOfChannels;
% t = ceil(fs/fSize);
% % create normally distributed noise.
% wn = randn(1,2*(t*fSize));
% % create noise with 17 dB decrease in power per octave. 
% amn = ambientHighFreq(2*fs);
% 
% 
% % normalization
% wn = wn - mean(wn);
% wn = wn./(max(abs(wn)));
% 
% amn = amn - mean(amn);
% amn = amn./max(abs(amn));
% 
% 
% 
% 
% fstop = 700;
% fstart = 1200;
% % lowpass and highpass filter signal to create ambient noise according to
% % figure in marine acoustics book (Hovem)
% [hpF,lpF] = designFilter(fs,fstop,fstart);
% wn = filter(lpF.Coefficients,1,wn);
% amn = filter(hpF.Coefficients,1,amn);
% 
% % add the two sort of noises to create a single noise array.
% noi = wn+amn;



% f = [1,1000,logspace(3,4,Fs),logspace(4,5,Fs)];
f = [1,1000,logspace(3,5,Fs)];
% amp = [1,1,logspace(0,-17/20,Fs),logspace(-17/20,-17/20*2,Fs)];
amp = [1,1,logspace(0,-17/20*2,Fs)];
% figure; loglog(f,amp)

indx = 0;
for i = Fs/2:length(f)-1
    if f(i-1) < Fs/2 && Fs/2 < f(i+1)
        indx = i;
    end
end
f = f(2:indx);
f(end) = Fs/2;
amp = amp(2:indx);
f2 = linspace(10,999,100)/(Fs/2);
amp2 = ones(100,1);
% figure; loglog(f,amp)
f = [0,f2,f./(Fs/2)];
m = [1,amp2',amp];



b1 = fir2(5000,f,m);
% [h1,w] = freqz(b1,1,length(b1));
% figure
% semilogx(f*96000/2,20*log10(m),w/pi*96000/2,20*log10(abs(h1)))
% xlabel('\omega / \pi');
% lgs = {'Ideal','fir2 default'};
% legend(lgs)


noise = randn(15*Fs,1);

ambNoise = filter(b1,1,noise);

numFrames = floor(length(ambNoise)/fSize);

% noise per 1muPa
noi = ambNoise./(10^-6);

% create power spectral density of noise signal
nfft = 2^nextpow2(Fs);
AmbientN = fft(noi,nfft);
AmbientN = AmbientN(1:nfft/2+1);
AmbientNW = (1/(Fs*nfft)).*abs(AmbientN).^2;
AmbientNW(2:end-1) = 2*AmbientNW(2:end-1);
% freq = 0:Fs/nfft:Fs/2;
% loglog(freq,AmbientNW)
% Noise level power per frequency relative to 1 muPa 
ANL = 10*log10(AmbientNW);
% Mean noise level for up to 1000 Hz.
meanANL =mean(ANL(100:1100));

% add noise gain according to figure 11.8 in hovem with correction
correction = meanANL - 50;
NOISE = 20*log10(noi)-correction + 4*(sS-1);
noi = 10.^(NOISE./20);
noise = sign(real(noi(1:numFrames*fSize))).*...
    (abs(noi(1:numFrames*fSize)));

noise = noise(Fs:end);

end%function
