function [hpFilt, lpFilt] = designFilter(fs,f1,f2)
% designFilter - design low pass and high pass filters according to the
%                wanted properties
% 
% The function returns the filter coefficients for the two filters
% 
% [hpFilt, lpFilt] = designFilter(fs,fstop,fstart)
% 
% Input:
% fs - sampling rate
% f1 - stop-/passband frequency
% f2 - stop-/passband frequency
% 
% Output:
% hpFilt - an object containing filter coefficients for high pass filter
% lpFilt - an object containing filter coefficients for low pass filter
% 
% Last modified 22.09.2014 by
% Frank Hetland & Leo Hauge


% create filters
hpFilt = designfilt('highpassfir','StopbandFrequency',2*f1/fs, ...
         'PassbandFrequency',2*f2/fs,'PassbandRipple',0.2, ...
         'StopbandAttenuation',65,'DesignMethod','kaiserwin');
     
lpFilt = designfilt('lowpassfir','StopbandFrequency',2*f2/fs, ...
         'PassbandFrequency',2*f1/fs,'PassbandRipple',0.2, ...
         'StopbandAttenuation',65,'DesignMethod','kaiserwin');

end%function