%% Create doppler matrix for all channels and paths with surface reflections
function [doppMat,I] = dopplerSpread(fs,U,r,c,fc,SrcAngle,RcvrAngle,BW, frameSize)

% doppMat{nChannels}{1} = 0;
% MI{nChannels}{1} = 0;
% Is{nChannels} = 0;


rho = 1000; % density water, assumed constant
% mean sound speed
c = mean(c);
% Mean square surface slope
if U >= 1
    s2 = 0.0046*log(2.1*U^2);
else
    s2 = 0.0034;
end

% time
tau = linspace(0,1/10,round(fs/10));
% Initial intensity
I0 = 1e10; %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Init
A0 = 1;
% pulse length
pulseL = 12;%round(fs/BW); %samples

% Calculate characteristic elongation time in ms for all channels
% for n = 1:nChannels
    rmat = r;
    [h,~] = size(rmat);
%     Is{n}{m}(1:length(I))
    
    tempScrAng = SrcAngle;
    signScr = sign(tempScrAng);
    tempRcvrAng = RcvrAngle;
    signRcvr = sign(tempRcvrAng);
    
    for m = 1:h
%         MI{n}{m} = zeros(h,1);
        angle = (signScr(m)*tempScrAng(m))*pi/180;
        angle2 = (signRcvr(m)*tempRcvrAng(m))*pi/180;
%         extract ranges from
        r1 = rmat(m,1);
        r2 = rmat(m,2);
        r3 = rmat(m,3);
        r4 = rmat(m,4);
        rr1 = r1 * ( r2 + r3 + r4 );
        rr2 = ( r1 + r2 + r3 ) * r4;
        rrSum = r1 + r2 + r3 + r4;
        
        % Charactristic elongation time
        L1 = 2*rr1/rrSum*(s2/c)*(1-exp((-angle)/(atan(sqrt(s2)))));
        L2 = 2*rr2/rrSum*(s2/c)*(1-exp((-angle2)/(atan(sqrt(s2)))));
        L = L1+L2;
        
        df = 0.128*U*fc*sin(angle);
        
        I = zeros(1,round(fs/10));
        for i = 1:fs/10
            if i<pulseL
                I(i) = erf(sqrt(tau(i)/L));
            else
                a = erf(sqrt(tau(i)/L));
                b = erf(sqrt((tau(i)-tau(pulseL))/L));
                I(i) = (a-b);
            end
        end
        % scattered intensity
%         I = I0*A0.*I./(r1 + r2 + r3 + r4)^2;
        maxIntensity = 10*log10(max(I(:)));
%         MI{n}(m) = maxIntensity;
        % Noise floor at -15 dB fro max intesity
        noiseFloor = (maxIntensity)-25;
        for i = 1:length(I)
                if I(i) == 0
                    I(i) = noiseFloor;
                else
                    I(i) = 10*log10(I(i));
                    if I(i)<=noiseFloor
                        I(i) = noiseFloor;
                    end
                end
        end
        % Extract signal with a minimum of noisefloor intensity level
        count = 10; % assume at least 10 samples of the impulse response
        while ( I(count) > noiseFloor ) && ( count<length(I) );
            count = count+1;
        end
        I = I(1:count);
        if U >=6
            sbl = (1.26e-3)/sin(angle)*U^1.57*fc^0.85;
        else
            sbl = (1.26e-3)/sin(angle)*6^1.57*fc^0.85;
            sbl = sbl*exp(1.2*(U-6));
        end
        I = I-sbl;
        % fs2 is the maximum updating frequency
        fs2 = (fs/frameSize);
        
        % res=94 is the maximum number of changing impulse responses for a
        % frame size of 1024 samples. It is based on fs/framesize. 
        filterRes = 22;
        res = ceil(fs2)+filterRes; % ceil to have at least 1 seconds
        I = 10.^(I./10);
        
        % assuming plane wave, and convert to sound pressure where,
        % p = sqrt(I/(rho*c)    ,   rho is the water density c is the mean
        % water sound speed. Assuming rho is constant at 1000 kg/m^3
        SP = sqrt(I);%./(rho*c));
        SP = ones(res,1)*SP;
        
        % Multiply to acchieve correct amplitudes for the impulse responses
        h = SP.*randn(res,count);
%         MI{n}{m}(1:res,1:count) = h;
        % Low pass filter to create a more slow varying change from scatter
        % impuse responses
        if df> (fs2/4)
            df = (fs2/4);
        end
        [b,a] = fir1(filterRes,(df)/(fs2/2),'low');
%         [b,a] = cheby2(filterRes,6,(df)/(fs2));
        hmat = zeros(size(h));
        for nn = 1:count
            hmat(:,nn) = filter(b,a,h(:,nn));
        end
%         figure;
%         freqz(b,a)
%         Is{n}{m} = I(1:count);
        doppMat{m}=hmat(filterRes:end,:);
        I = 10*log10(I);
        
    end
