%% Header Realtime

% Input:
% handles - object where:
% handles.settings.Mic - Microphone object
% handles.settings.Speaker - Speaker object
% handles.settings.noise - Noise with 17 dB power decrease per decade
% handles.class1.dist - Distance for the reflections !!!
% handles.class1.dir - Distance for the line of sight
% handles.class1.depth - Ocean depth
% handles.settings.Fs - Sampling frequency
% handles.settings.samplesPerFrame - Frame size
% handles.settings.c0 - Sound speed in water
% handles.settings.samplesPerFrame - Frame size
% handles.settings.alpha - Absorption [dB/km]
% handles.t.transmitterSens - Transducer transmit sensitivity
% handles.t.receiverSens - Transducer receive sensitivity
% handles.settings.TransducerGain - Transducer directivity

% Mic and Speaker for reading and sending audio
Mic = handles.settings.Mic; 
Speaker = handles.settings.Speaker;

%% Physical things
% Array of noise corresponding to the length of one frame
noise = handles.settings.noise';
% sound speed profile
c = handles.settings.SSP;
cmean = mean(c);
% Depth array
zDepth = handles.settings.SSP_z;
% Sampling frequency
Fs = handles.settings.Fs;
% Water temperature
temp = handles.settings.temp;
% carrier frequency
fc = handles.settings.carrierF;
% Water depth (max)
depth = handles.class1.depth;
% Frame size. Size of the array under computation. Both size of incoming
% and outgoing
fSize = handles.settings.samplesPerFrame;
% Number of nodes in the network
nodes = handles.settings.numbOfInOut;

% Sea State
seaState = handles.settings.seastate;
% wave height
waveHeight = handles.settings.waveHeight;


%% Transducer
% Transmitter sensitivity
transmittSens=handles.t.transmitterSens;
% Receiver sensitivity
recSens= handles.t.receiverSens;
% AttUTBIN
AttUTBin = 51; %51;
% Attenuation Out-UTB
AttOutUTB = 58;

% Gain vs beam pattern
% % transducerGain = handles.settings.TransducerGain;
BW = handles.settings.Bandwidth;
txPos = handles.class1.VerticalTx;
% rxPos = handles.class1.Rx2D;

%% Produced with bellhop. All are arrays of size 200. Only Narr # have values
% The positions in the arrays are corresponding to each other
% nArrival contains all arrival information for all bellhop runs 

nArrival = handles.settings.nArrival; 
% nChannels - number of multipath channels
nChannels = handles.class1.nChannel; %length(nArrival);

for n = 1:nChannels % multipaths
    % delay of all rays in seconds
    delay{n} = nArrival{n}.delay;
    % Number of rays hitting the target
    Narr{n} = nArrival{n}.Narr;
    % Complex amplitude of the rays hitting the target relative 1
    amp{n} = nArrival{n}.A;
    % Angle of ray out from source, 0 degrees is horizontal. Upwards have an
    % negative sign, while positive angles are downwards
    SrcAngle{n} = nArrival{n}.SrcAngle;
    % Angle of incoming ray to target
    RcvrAngle{n} = nArrival{n}.RcvrAngle;
    % Number of surface bounces
    NumTopBnc{n} = nArrival{n}.NumTopBnc;
    % Numer of bottom bounces
    NumBotBnc{n} = nArrival{n}.NumBotBnc;
    

end