function varargout = plotbty( btyfil,handles )

% Plot the bathymetry file
% usage: plotbty( btyfil )
% where btyfil is the BaThYmetry file (the extension is optional)
% e.g. plotbty( 'foofoo' )
%
% plots the BaThymetrY file used by Bellhop
% MBP July 1999

global xBot NbtyPts
global units

BotBTY = '*';   % flag to read from bty file
depthB = inf;
rBox   = inf;
readbty( btyfil, BotBTY, depthB, rBox ) % read the bathymetry data

% copy, removing +/- inf values
NbtyPts = NbtyPts - 2;
r = xBot( 1, 2 : end - 1 );
z = xBot( 2, 2 : end - 1 );

% set labels in m or km
xlab     = 'Range (m)';
if ( strcmp( units, 'km' ) )
  r      = r / 1000.0;
  xlab   = 'Range (km)';
end
%%

hold on
xlabel( xlab )
ylabel( 'Depth (m)' )

% close the polygon
zmax      = max( z );
thickness = ( max( z ) - min( z ) );
thickness = max( thickness, 1 );   % make sure there's some thickness

 
Xdist=max(handles.class1.nodesChannel(:,3)); % max Horizontal 
Ydist=max(handles.class1.nodesChannel(:,5)); % max Y-direction
Xdist=linspace(0,Xdist,length(r));
Ydist=linspace(-Ydist-1,Ydist+1,length(r));
[X,Y] = ndgrid(Xdist, Ydist);
Z=repmat(z,length(Y),1);
mesh(X',Y',Z)


% % % % r( NbtyPts + 1 ) = r( NbtyPts );
% % % % z( NbtyPts + 1 ) = zmax + thickness;
% % % % r( NbtyPts + 2 ) = r( 1 );
% % % % z( NbtyPts + 2 ) = zmax + thickness;

% % % % Ydist=max(handles.class1.nodesChannel(:,5)); % max Y-direction
% % % % Ydist=linspace(-Ydist,Ydist,length(r));
% % % % earthbrown = [ 0.5 0.3 0.1 ];
% % % % h          = fill3( r,Ydist,z, earthbrown );


set( gca, 'YDir', 'Reverse' )   % plot with depth-axis positive down

if ( nargout == 1 )
   varargout( 1 ) = { h };   % return a handle to the figure
end
hold off
