function varargout = plotray( rayfil, handles)

% Plot the RAYfil produced by Bellhop
% usage: plotray( rayfil )
% where rayfil is the ray file (extension is optional)
% e.g. plotray( 'foofoo' )
%
% MBP July 1999
global units jkpsflag alphaArr itterator
itterator = 0;
if ( strcmp( rayfil, 'RAYFIL' ) == 0 && isempty( findstr( rayfil, '.ray' ) ) )
    rayfil = [ rayfil '.ray' ]; % append extension
end

% plots a BELLHOP ray file

fid = fopen( rayfil, 'r' );   % open the file
if ( fid == -1 )
    disp( rayfil );
    errordlg( 'No ray file exists; you must run BELLHOP first (with ray ouput selected)', 'Error' );
end

% read header stuff

TITLE  = fgetl(  fid );
FREQ   = fscanf( fid, '%f', 1 );
NBEAMS = fscanf( fid, '%i', 1 );
DEPTHT = fscanf( fid, '%f', 1 );
DEPTHB = fscanf( fid, '%f', 1 );

% Extract letters between the quotes
nchars = strfind( TITLE, '''' );   % find quotes
TITLE  = [ TITLE( nchars( 1 ) + 1 : nchars( 2 ) - 1 ) blanks( 7 - ( nchars( 2 ) - nchars( 1 ) ) ) ];
TITLE  = deblank( TITLE );  % remove whitespace

% read rays

% set up axis lengths for publication
if ( jkpsflag )
    set( gcf, 'Units', 'centimeters' )
    set( gca, 'ActivePositionProperty', 'Position', 'Units', 'centimeters' )
    
    set( gca, 'Position', [ 2 2 14.0  7.0 ] )
    %set( gcf, 'PaperPosition', [ 3 3 19.0 10.0 ] )
end




% axis limits
rmin = +1e9;
rmax = -1e9;
zmin = +1e9;
zmax = -1e9;
alphaArr=[];
for ibeam = 1:NBEAMS
    alpha0    = fscanf( fid, '%f', 1 );
    alphaArr= [alphaArr alpha0];
    nsteps    = fscanf( fid, '%i', 1 );
    NumTopBnc = fscanf( fid, '%i', 1 );
    NumBotBnc = fscanf( fid, '%i', 1 );

           
            if isempty( nsteps ); break; end
            ray = fscanf( fid, '%f', [2 nsteps] );
            r = ray( 1, : );
            z = ray( 2, : );

            if ( strcmp( units, 'km' ) )
                r = r / 1000;   % convert to km
            end
% tempalpha0 = round(alpha0);
%     for i=1:handles.settings.Arr.Narr
%         if tempalpha0 == round(handles.settings.Arr.SrcAngle(i))
%              itterator=itterator+1;
            %lincol = 'kbgrcmy';
            %ii = NumBotBnc;
            %ii = mod( ii, 3 ) + 1;
            %plot( r, z, lincol(ii) );
            if NumTopBnc>1 && NumBotBnc>1
            else 
                % Get the length of range datapoints
                L= length(r); 
%                 M = max(r);
                % 3D!! 
                % Get the Y-direction to RX 
                yPos=handles.class1.Ydirections;
                % Get the Y-direction to TX
                yStart = handles.class1.YTx;
                % Make an Y-direction array, with length L 
                y = linspace (yStart,yPos,L);
                % Get the horizontal position of TX, important if NETWORK
                xLength=handles.class1.HorizontalTx; % ADD FOR NEW TX POS 
                % Get the datapoint for x.
                xPos =linspace(0,handles.class1.HorizontalRX,L); 
                
                % This is the most "correct" way for 2D, but it looks weird in 3D,
%            xPos= r*handles.class1.HorizontalRX/handles.class1.RealDistanceRX;         
%                Interpolate to get smoother graph.. but not perfect
%                 xPos=interp1(r,1:1/2:L+1/2);
%                  z=interp1(z, 1:1/2:L+1/2);
                
                z= smooth(z)';

                x= xPos+xLength;

                  
                  
                  
%                   y=zeros(L,1);
                if (NumTopBnc >= 1) && (NumBotBnc >= 1)
%                     plot( r, z, 'k' ) 
                    plot3(x,y,z,'k')
                    hold on % hits both boundaries
                elseif NumBotBnc >= 1
%                     plot( r, z, 'b'  )	% hits bottom only
                    plot3(x,y,z,'b')
                    hold on
                elseif NumTopBnc >= 1
%                     plot( r, z, 'g'  )	% hits surface only
                    plot3(x,y,z,'b')
                    hold on
                else
%                     plot( r, z, 'r' )
                    plot3(x,y,z,'r')
                    hold on
                end
            end
            
%         end
%     end
            % update axis limits
            rmin = min( [ r rmin ] );
            rmax = max( [ r rmax ] );
            zmin = min( [ z zmin ] );
            zmax = max( [ z zmax ] );
            if ( zmin == zmax ) % horizontal ray causes axis scaling problem
                zmax = zmin + 1;
            end
%             rmax=handles.class1.Rx(3);
            zmax=max(handles.settings.SSP_z);
%              axis( [ rmin,rmax , -1, zmax ] )
%             Horizontalmax= max(handles.class1.Rx(:,1));
%             axis([ 0,Horizontalmax, -1, max(handles.settings.SSP_z) ] )

            if rem( ibeam, fix( NBEAMS / 10 ) ) == 0,    % flush graphics buffer every 10th ray
                drawnow
            end
        
    
    
    %end
end	% next beam

fclose( fid );

set( gca, 'YDir', 'Reverse' )   % plot with depth-axis positive down

xlabel( 'Range (m)' )
if ( strcmp( units, 'km' ) )
    xlabel( 'Range (km)' )
end
ylabel( 'Range (m)' )
zlabel( 'Depth (m)' )
TITLE ='RAYTRACE';
title( TITLE )
grid on 
% hold off
zoom on

if ( nargout == 1 )
    varargout{ 1 } = findobj( 'Type', 'Line' );   % return a handle to the lines in the figure
end

% fixed size for publications
if ( jkpsflag )
    set( gca, 'Units', 'centimeters' )
    set( gca, 'Position', [ 2 2 14.0  7.0 ] )
    set(gcf, 'PaperPositionMode', 'auto');

    %set( gcf, 'Units', 'centimeters' )
    %set( gcf, 'PaperPosition', [ 3 3 19.0 10.0 ] )
    set( gcf, 'Units', 'centimeters' )
    set( gcf, 'Position', [ 3 15 19.0 10.0 ] )
end