function [spreadLossDir, spreadLossDist] = spreadLoss(dir,dist,depth)
% spreadLoss - intensity loss from spread function
% 
% This function calculated the spread loss of a sound wave
% 
% [spreadLossDir, spreadLossDist] = spreadLoss(dir,dist,depth)
% 
% Input:
% dir - line of sight distance from source to receiver
% dist - distances for reflections from source to receiver
% depth - ocean depth
% 
% Output:
% spreadLossDir - spread loss in dB for the line of sight
% spreadLossDist - spread loss in dB for the reflections
% 
% Last modified 09.12.2014 by
% Frank Hetland & Leo Hauge

% spherical spread with direct
if dir<=depth
    spreadLossDir = 10*log10(1/(dir^2));
    
    
    spreadLossDist = 10*log10(1./(dist.^2));
    
else % Cylindrical spread
    spreadLossDir = 10*log10(1./(dir));
    
    
    spreadLossDist = 10*log10(1./(dist));
end