function [handles] = transducerAngleGain(handles)
% transducerAngleGain - find the transducer gain and angle, and gains the 
% amplitude of the signal! 
% 
% This functions computes the directivity of a transducer for angles
% 
% [angle, angleDir, gain] = transducerAngleGain(handles)
% 
% Input:
% handles - object where:
% handles.class1.dist - distances for reflections from source to receiver
% handles.class1.Rx - receiver position
% handles.class1.dir - line of sight distance from source to receiver
% handles.t.transducer21kHz - 
% handles.transAng; 
% 
% Output:
% angle  - angle between transmitter and receiver for reflections
% angleDir - angle between transmitter and receiver for line of sight
% gain - transducer gain for the given angles
% new Amplitude! 

% Last modified 12.10.2014 by
% Frank Hetland & Leo Hauge
for i=1:handles.class1.nChannel
    numRay =  handles.settings.nArrival{i}.Narr;
    % handles.settings.Arr.NumTopBnc
    % handles.settings.Arr.NumBotBnc
    angles =  handles.settings.nArrival{i}.SrcAngle;
    roundAng = round(angles);
    % dist = handles.class1.dist;
    % Rx = handles.class1.Rx;
    % dir= handles.class1.dir;
    
    % Seperate out the different different frequencies.
    % for i=1:length(handles.t.freq_name)-1
    %     transducer{i}=eval(['handles.t.transducer' handles.t.freq_name{i}]);
    % end
    
    transducer=handles.t.transducerCarrierFreq;
    
    % transducer21kHz=handles.t.transducer21kHz;
    transducerangle= handles.t.transAng;
    % transducerangle = -10;
    % Find the middle of the transducer data
    midLength = floor(length(transducer)/2);
    % Direct angle from the transducer.
    % angleDir=round(acos(Rx(2)/dir)*180/pi)-transducerangle;
    
    angle{i} = zeros(1,numRay);
    gain{i} = zeros(1,numRay);
    % for i=1:size(dist,2) % finds the amount of reflections
    for j=1:numRay % seperate top and bottom reflections
        angle{i}(j) = sign(roundAng(j))*roundAng(j)+transducerangle;
        %         disp(angle(j))
        %         if j == 1
        %             gain(j)=transducer21kHz((angle(j)));
        if (mod(angle{i}(j),2)==1) %Odd numbers, calculate the average
            %divide on 2 because it is two degrees between each number.
            temp1=transducer(midLength+(angle{i}(j)+1)/2+1);
            temp2=transducer(midLength+(angle{i}(j)-1)/2+1);
            gain{i}(j)=(temp1+temp2)/2;
        else
            
            gain{i}(j)=transducer(midLength+(angle{i}(j)/2+1));
        end
        if handles.settings.nArrival{i}.A(j)>0
        handles.settings.nArrival{i}.A(j)=handles.settings.nArrival{i}.A(j)-abs(gain{i}(j));
        else
            handles.settings.nArrival{i}.A(j)=handles.settings.nArrival{i}.A(j)+abs(gain{i}(j));
        end
    end
    
    
end
handles.settings.angle=angle;
handles.settings.gain = gain;
end

