function alpha = waterAbsorptionCoefficient(fc,T,C,D)
%% M TA INN HANDLES
% waterAbsorptionCoefficient - find the transducer gain and angle
% 
% This functions computes the directivity of a transducer for angles
% 
% alpha = waterAbsorptionCoefficient(handles)
% 
% Input:
% handles - object where:
% handles.settings.T - Temperature in centigrades
% handles.settings.S - Salinity
% handles.class1.depth - Ocean depth
% 
% Output:
% alpha  - Absorption coefficient in [dB/km]
% 
% Last modified 12.10.2014 by
% Frank Hetland & Leo Hauge

%% Francois and Garrison Formula p. 57 in Hovem's Marine Acoustics
% T = 10;%handles.settings.T; 

S = 35; %handles.settings.S;      
% C = 1500;
% D = 300;%handles.settings.Rx(1);
fc = fc/1000;


% temp in kelvin
Kelvin=T+273;
PH=7.8;

if (T <=20)
    A3=4.937e-4-2.59e-5*T+9.11e-7*T^2-1.5e-8*T^3;
else
    A3 = 3.964e-4 - 1.146e-5*T + 1.45e-7*T^2 - 6.5e-10*T^3;
end
P3=1-3.38e-5*D+D^2*10e-10;

A2=21.44*S/C*(1+0.025*T);
P2=1-1.37e-4*D+6.2e-9*D^2;
f2=8.17*10^(8-1990/Kelvin)/(1+0.0018*(S-35));



A1=8.86/C*10^(0.78*PH-5);
P1=1;
f1=2.8*(S/35)^0.5*10^(4-1245/Kelvin);


alpha1=A1*P1*f1*fc.^2./(fc.^2+f1^2);
alpha2=A2*P2*f2*fc.^2./(fc.^2+f2^2);
alpha3=A3*P3*fc.^2;
alpha=alpha1+alpha2+alpha3;
end